import React from "react";
import clsx from "clsx";
import styles from "./styles.module.css";

type ServiceItem = {
  title: string;
  Svg: React.ComponentType<React.ComponentProps<"svg">>;
  description: JSX.Element;
};

const PrivateServicesList: ServiceItem[] = [
  {
    title: "Chat",
    Svg: require("@site/static/img/undraw_chat_tjo_space.svg").default,
    description: (
      <>
        Use <a href="https://chat.tjo.space">chat.tjo.space</a> Metrix server
        which you can use to chat with other users of tjo.space or world wide
        with anyone else on the Matrix network.
      </>
    ),
  },
  {
    title: "Cloud",
    Svg: require("@site/static/img/undraw_cloud_tjo_space.svg").default,
    description: (
      <>
        Use <a href="https://cloud.tjo.space">cloud.tjo.space</a> Nextcloud
        server as a personal cloud to store your <b>Photos</b>, <b>Videos</b>,
        <b>Files</b>, <b>Calendar</b>, <b>Contacts</b> as well as share all that
        with other users of tjo.space or anyone else.
      </>
    ),
  },
  {
    title: "Code",
    Svg: require("@site/static/img/undraw_code_tjo_space.svg").default,
    description: (
      <>
        Use <a href="https://code.tjo.space">code.tjo.space</a> Gitea server as
        a Git repository and CI/CD system.
      </>
    ),
  },
  {
    title: "Paperless",
    Svg: require("@site/static/img/undraw_paperless_tjo_space.svg").default,
    description: (
      <>
        Use <a href="https://paperless.tjo.space">paperless.tjo.space</a>{" "}
        Paperless server to archive your documents and make them searchable. Can
        be connected to your email provider so that all attachments are
        autmatically archived.
      </>
    ),
  },
  {
    title: "RSS",
    Svg: require("@site/static/img/undraw_rss_tjo_space.svg").default,
    description: (
      <>
        Use <a href="https://rss.tjo.space">rss.tjo.space</a> server as a RSS
        reader for all of your news, blogs and podcasts.
      </>
    ),
  },
];

const PublicServicesList: ServiceItem[] = [
  {
    title: "Search",
    Svg: require("@site/static/img/undraw_search_tjo_space.svg").default,
    description: (
      <>
        Use <a href="https://search.tjo.space">search.tjo.space</a> private meta
        search engine that doesn't track you.
      </>
    ),
  },
  {
    title: "Send",
    Svg: require("@site/static/img/undraw_send_tjo_space.svg").default,
    description: (
      <>
        Use <a href="https://send.tjo.space">send.tjo.space</a> to create
        private temporary link to share files up to 20GB in size.
      </>
    ),
  },
  {
    title: "Watch",
    Svg: require("@site/static/img/undraw_yt_tjo_space.svg").default,
    description: (
      <>
        Use <a href="https://yt.tjo.space">yt.tjo.space</a> an Invidious server
        to privatly watch YouTube videos.
      </>
    ),
  },
];

const UpcomingServicesList: ServiceItem[] = [
  {
    title: "Mail",
    Svg: require("@site/static/img/undraw_mail_tjo_space.svg").default,
    description: (
      <>
        Use <a href="https://mail.tjo.space">mail.tjo.space</a> to get your
        personal <b>@tjo.space</b> email address.
      </>
    ),
  },
  {
    title: "Vault",
    Svg: require("@site/static/img/undraw_vault_tjo_space.svg").default,
    description: (
      <>
        Use <a href="https://vault.tjo.space">vault.tjo.space</a> Bitwarden
        server to securily store your passwords.
      </>
    ),
  },
  {
    title: "VPN",
    Svg: require("@site/static/img/undraw_vpn_tjo_space.svg").default,
    description: (
      <>
        Use <a href="https://vpn.tjo.space">vpn.tjo.space</a> Tailscale server
        to securily connect with other tjo.space users or use one of available
        exit locations to have secure internet connection.
      </>
    ),
  },
];

function Service({ title, Svg, description }: ServiceItem) {
  return (
    <div className={clsx("col col--4 service")}>
      <div className="text--center">
        <Svg className={styles.featureSvg} role="img" />
      </div>
      <div className="text--center padding-horiz--md">
        <h3>{title}</h3>
        <p>{description}</p>
      </div>
    </div>
  );
}

export default function HomepageFeatures(): JSX.Element {
  return (
    <section className={styles.features}>
      <div className="container">
        <h3>Public Services</h3>
        <div className={clsx("row", styles.row)}>
          {PublicServicesList.map((props, idx) => (
            <Service key={idx} {...props} />
          ))}
        </div>
        <h3>Private Services</h3>
        <div className={clsx("row", styles.row)}>
          {PrivateServicesList.map((props, idx) => (
            <Service key={idx} {...props} />
          ))}
        </div>
        <h3>Upcoming Services (not yet available)</h3>
        <div className={clsx("row", styles.row)}>
          {UpcomingServicesList.map((props, idx) => (
            <Service key={idx} {...props} />
          ))}
        </div>
      </div>
    </section>
  );
}
